

Optimization
============

.. contents::
    :local:

BaseOptimizer
+++++++++++++

.. autoclass:: aftercovid.optim.sgd.BaseOptimizer
    :members:

SGDOptimizer
++++++++++++

.. autoclass:: aftercovid.optim.SGDOptimizer
    :members:
